@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2006 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2006 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -12,9 +12,11 @@
 ##############################################################################
 """Browser views for events.
 
-$Id: event.py 104362 2009-09-18 20:32:27Z yuppie $
+$Id: event.py 113210 2010-06-06 15:09:46Z hannosch $
 """
 
+import time
+
 from zope.app.form.browser import DatetimeI18nWidget
 from zope.component import adapts
 from zope.component import getUtility
@@ -30,19 +32,18 @@ from zope.schema import URI
 from zope.schema.interfaces import IVocabularyFactory
 
 from Products.CMFCore.interfaces import IMetadataTool
+from Products.CMFDefault.browser.utils import decode, ViewBase
 from Products.CMFDefault.formlib.form import ContentEditFormBase
 from Products.CMFDefault.formlib.form import DisplayFormBase
 from Products.CMFDefault.formlib.schema import EmailLine
 from Products.CMFDefault.formlib.schema import ProxyFieldProperty
 from Products.CMFDefault.formlib.schema import SchemaAdapterBase
 from Products.CMFDefault.formlib.vocabulary import SimpleVocabulary
+from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 
 from Products.CMFCalendar.interfaces import IMutableEvent
 from Products.CMFCalendar.utils import Message as _
 
-from zope.app.pagetemplate import ViewPageTemplateFile
-from Products.CMFDefault.browser.utils import decode, ViewBase
-import time
 
 class EventTypeVocabulary(object):
 
